""" Constant values """

# Data types
NUMBER = 'N'
STRING = 'S'
BINARY = 'B'
NUMBER_SET = 'NS'
STRING_SET = 'SS'
BINARY_SET = 'BS'
LIST = 'L'
BOOL = 'BOOL'
MAP = 'M'
NULL = 'NULL'

NONE = 'NONE'

# ReturnValues
ALL_OLD = 'ALL_OLD'
ALL_NEW = 'ALL_NEW'
UPDATED_OLD = 'UPDATED_OLD'
UPDATED_NEW = 'UPDATED_NEW'

# ReturnConsumedCapacity
INDEXES = 'INDEXES'
TOTAL = 'TOTAL'
